canonical_root

Function canonical_root 

pub fn canonical_root(root: &Path) -> Result<PathBuf>
Canonicalize root, creating it first if it does not yet exist.

Errors

Returns an error if the directory cannot be created or canonicalized.