pub fn copy_single_large(src: &Path, tmp: &Path, len: u64) -> Result<u64>Expand description
Copy a single large file via linked splice SQEs.
This is the entry point used by the portable copy ladder in crate::copy
when io_uring is available and the file is 1–64 MiB.